clear all
%
data_file_name  = ['Fig9_',datestr(now)];   % file name wish to save the data with
repeat_num      = 20;                       % number of repetitions
order_cyc_cutoff = 3;                       % cut-off number of cycles for succesful sorting, not inclusive
plot_option     = 0;                        % 1: plot each simulation 0: do not plot;
%% SET PARAMETERS
% NETWORK SETUP
n = 33;                                 % Number of segments

epsilon = 1;                            % epsilon   Asymptotic parameter

% SYNAPTIC STRENGTH
g_c     =   0.1;                        % g_c: chemical synaptic conductance from V2a-II to V2a-I
g_c_II  =   7.15;                       % g_{c,II}: chemical synaptic conductance from V2a-I to V2a-II
% BIAS CURRENT
I_I     =   1/(1-exp(-3));              % I_I :Bias current of leading V2a-I neuron
I_II    =   1.2;                        % I_II: Bias current of V2a-II neurons

cyc_nums = 3;                           % Number of cycles wish to simulate

g_g_all         = [0.2:0.2:1.4];        % List of values for g_g: gap junction coupling strength
DeltaI_all      = [-0.01:-0.01:-0.11];  % List of values for Delta I: Difference in bias current between leader and follower V2a-I neurons

%%
order_cyc_log   = zeros(length(DeltaI_all),length(g_g_all),repeat_num);
success_log     = zeros(length(DeltaI_all),length(g_g_all),repeat_num);

rng_log=cell(1,repeat_num);
simul_fail_log = zeros(length(DeltaI_all),length(g_g_all),repeat_num);
success_log = zeros(length(DeltaI_all),length(g_g_all),repeat_num);
simul_fail_iterations = zeros(1,repeat_num); 
%%
for rid = 1:repeat_num
    rng shuffle;
    rng_now = rng;
    rng_log{rid} = rng_now;
    simul_time = 0;
    for gid = 1:length(g_g_all)
        for dIid=1:length(DeltaI_all)
            rng(rng_now);
            time_now = datestr(now);
            [order_cyc,spk_check,simul_time] = SimulateModel_SortingCheck(n,epsilon,g_g_all(gid),g_c,g_c_II,I_I,DeltaI_all(dIid),I_II,cyc_nums,plot_option);
            if ~isempty(data_file_name)
                data_file_name_now = [data_file_name,'_',num2str(rid)];
                save(data_file_name_now)
            end
            if simul_time<0
                simul_fail_iterations(rid)=1; 
                simul_fail_log(dIid,gid,rid)=1;
            else
                if ~isempty(order_cyc) && (spk_check == 0)
                    order_cyc_log(dIid,gid,rid)= order_cyc;
                    if order_cyc<order_cyc_cutoff
                        success_log(dIid,gid,rid) = 1;
                    end
                end
            end
        end
    end
end

%% Plot Sorting Success Rate

valid_repeat_num =sum(simul_fail_log<1,3);
success_count = sum(success_log,3);
sorting_rate = success_count./valid_repeat_num;

%% PLOT RESULT

figure;
imagesc(g_g_all,DeltaI_all,sorting_rate)
axis xy
xl= xlabel('$g_{g}$');
set(xl,'interpreter','latex')
yl= ylabel('$\Delta I$');
set(yl,'interpreter','latex')
colorbar


figure;
imagesc(g_g_all,DeltaI_all,sum(simul_fail_log,3))
axis xy
xl= xlabel('$g_{g}$');
set(xl,'interpreter','latex')
yl= ylabel('$\Delta I$');
set(yl,'interpreter','latex')
colorbar

if ~isempty(data_file_name)
    save(data_file_name)
end
